Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Redis ¶
type Redis struct {
// host:port address.
Addr string `yaml:"addr"`
// Optional password. Must match the password specified in the
// requirepass server configuration option.
Password string `yaml:"password"`
// Database to be selected after connecting to the server.
DB int `yaml:"db"`
// Dial timeout for establishing new connections.
// Default is 5 seconds.
DialTimeout time.Duration `yaml:"dialTimeout"`
// Timeout for socket reads. If reached, commands will fail
// with a timeout instead of blocking. Use value -1 for no timeout and 0 for default.
// Default is 3 seconds.
ReadTimeout time.Duration `yaml:"readTimeout"`
// Timeout for socket writes. If reached, commands will fail
// with a timeout instead of blocking.
// Default is ReadTimeout.
WriteTimeout time.Duration `yaml:"writeTimeout"`
// Maximum number of socket connections.
// Default is 10 connections per every CPU as reported by runtime.NumCPU.
PoolSize int `yaml:"poolSize"`
// Minimum number of idle connections which is useful when establishing
// new connection is slow.
MinIdleConns int `yaml:"minIdleConns"`
// Connection age at which client retires (closes) the connection.
// Default is to not close aged connections.
MaxConnAge time.Duration `yaml:"maxConnAge"`
// Amount of time client waits for connection if all connections
// are busy before returning an error.
// Default is ReadTimeout + 1 second.
PoolTimeout time.Duration `yaml:"poolTimeout"`
// Amount of time after which client closes idle connections.
// Should be less than server's timeout.
// Default is 5 minutes. -1 disables idle timeout check.
IdleTimeout time.Duration `yaml:"idleTimeout"`
// Frequency of idle checks made by idle connections reaper.
// Default is 1 minute. -1 disables idle connections reaper,
// but idle connections are still discarded by the client
// if IdleTimeout is set.
IdleCheckFrequency time.Duration `yaml:"idleCheckFrequency"`
// Instance
*redis.Client
}
type RedisCluster ¶
type RedisCluster struct {
// A seed list of host:port addresses of cluster nodes.
Addrs []string `yaml:"addrs"`
// Optional password. Must match the password specified in the
// requirepass server configuration option.
Password string `yaml:"password"`
// Database to be selected after connecting to the server.
MaxRedirects int `yaml:"maxRedirects"`
// Dial timeout for establishing new connections.
// Default is 5 seconds.
DialTimeout time.Duration `yaml:"dialTimeout"`
// Timeout for socket reads. If reached, commands will fail
// with a timeout instead of blocking. Use value -1 for no timeout and 0 for default.
// Default is 3 seconds.
ReadTimeout time.Duration `yaml:"readTimeout"`
// Timeout for socket writes. If reached, commands will fail
// with a timeout instead of blocking.
// Default is ReadTimeout.
WriteTimeout time.Duration `yaml:"writeTimeout"`
// Maximum number of socket connections.
// Default is 10 connections per every CPU as reported by runtime.NumCPU.
PoolSize int `yaml:"poolSize"`
// Minimum number of idle connections which is useful when establishing
// new connection is slow.
MinIdleConns int `yaml:"minIdleConns"`
// Connection age at which client retires (closes) the connection.
// Default is to not close aged connections.
MaxConnAge time.Duration `yaml:"maxConnAge"`
// Amount of time client waits for connection if all connections
// are busy before returning an error.
// Default is ReadTimeout + 1 second.
PoolTimeout time.Duration `yaml:"poolTimeout"`
// Amount of time after which client closes idle connections.
// Should be less than server's timeout.
// Default is 5 minutes. -1 disables idle timeout check.
IdleTimeout time.Duration `yaml:"idleTimeout"`
// Frequency of idle checks made by idle connections reaper.
// Default is 1 minute. -1 disables idle connections reaper,
// but idle connections are still discarded by the client
// if IdleTimeout is set.
IdleCheckFrequency time.Duration `yaml:"idleCheckFrequency"`
// Instance
*redis.ClusterClient
}
func (*RedisCluster) Connect ¶
func (r *RedisCluster) Connect() error
Source Files
¶
- redis.go
- redis_cluster.go
- xorm.go
Click to show internal directories.
Click to hide internal directories.